class TDM_HUD extends DM_HUD;

var Texture TeamIcon[4];
var() color TeamColor[4];
var() color AltTeamColor[4];

var() name OrderNames[16];
var() int NumOrders;

simulated function HUDSetup(canvas canvas)
{
	Super.HUDSetup(canvas);
	if ( bUseTeamColor && (PawnOwner.PlayerReplicationInfo != None)
		&& (PawnOwner.PlayerReplicationInfo.Team < 4) )
	{
		HUDColor = TeamColor[PawnOwner.PlayerReplicationInfo.Team];
		SolidHUDColor = HUDColor;
		if ( Level.bHighDetailMode )
			HUDColor = Opacity * 0.0625 * HUDColor;
	}
	DrawGameSynopsis(Canvas);
}

simulated function DrawGameSynopsis(Canvas Canvas)
{
local PlayerReplicationInfo PRI;
local int i, NumTeams;
local bool bRed, bBlue, bGreen, bGold;

	for ( i=0; i<32; i++ )
		{
		if (PlayerPawn(Owner).GameReplicationInfo.PRIArray[i] != None)
			{
			PRI = PlayerPawn(Owner).GameReplicationInfo.PRIArray[i];
			if ( PRI.Team == 0 )
				bRed = True;
			else if ( PRI.Team == 1 )
				bBlue = True;
			else if ( PRI.Team == 2 )
				bGreen = True;
			else if ( PRI.Team == 3 )
				bGold = True;
			}
		}
	if (bRed)
		NumTeams++;
	if (bBlue)
		NumTeams++;
	if (bGreen)
		NumTeams++;
	if (bGold)
		NumTeams++;

	DrawTeamScores(Canvas, NumTeams);
}

simulated function DrawTeamScores(Canvas Canvas, int NumTeams)
{
local float Xpos, Ypos, XL, YL;
local Texture RedIcon, BlueIcon, GreenIcon, GoldIcon;
local string Red, Blue, Green, Gold;

	Xpos = Canvas.ClipX - 64;
	Ypos = Canvas.ClipY * 0.5 - 36 * NumTeams;

	Red = PRI(PlayerPawn(Owner).PlayerReplicationInfo).RedIcon;
	RedIcon = Texture(DynamicLoadObject(Red, class'Texture'));
	Canvas.Font = MyFonts.GetHugeFont( Canvas.ClipX );
	Canvas.DrawColor = WhiteColor;
	Canvas.SetPos( Xpos, Ypos );
	Canvas.Style = ERenderStyle.STY_Translucent;
	Canvas.DrawIcon( RedIcon, 1 );
	Canvas.Style = ERenderStyle.STY_Normal;
	Canvas.DrawColor = RedColor;
	Canvas.StrLen( PRI(PlayerPawn(Owner).PlayerReplicationInfo).RedScore, XL, YL );
	Canvas.SetPos( Xpos - XL - 4, Ypos + 32 - 0.5 * YL );
	Canvas.DrawText( PRI(PlayerPawn(Owner).PlayerReplicationInfo).RedScore, false );

	Ypos += 80;
	Blue = PRI(PlayerPawn(Owner).PlayerReplicationInfo).BlueIcon;
	BlueIcon = Texture(DynamicLoadObject(Blue, class'Texture'));
	Canvas.Font = MyFonts.GetHugeFont( Canvas.ClipX );
	Canvas.DrawColor = WhiteColor;
	Canvas.SetPos( Xpos, Ypos );
	Canvas.Style = ERenderStyle.STY_Translucent;
	Canvas.DrawIcon( BlueIcon, 1 );
	Canvas.Style = ERenderStyle.STY_Normal;
	Canvas.DrawColor = BlueColor;
	Canvas.StrLen( PRI(PlayerPawn(Owner).PlayerReplicationInfo).BlueScore, XL, YL );
	Canvas.SetPos( Xpos - XL - 4, Ypos + 32 - 0.5 * YL );
	Canvas.DrawText( PRI(PlayerPawn(Owner).PlayerReplicationInfo).BlueScore, false );

	if ( Numteams > 2 )
		{
		Ypos += 80;
		Green = PRI(PlayerPawn(Owner).PlayerReplicationInfo).GreenIcon;
		GreenIcon = Texture(DynamicLoadObject(Green, class'Texture'));
		Canvas.Font = MyFonts.GetHugeFont( Canvas.ClipX );
		Canvas.DrawColor = WhiteColor;
		Canvas.SetPos( Xpos, Ypos );
		Canvas.Style = ERenderStyle.STY_Translucent;
		Canvas.DrawIcon( GreenIcon, 1 );
		Canvas.Style = ERenderStyle.STY_Normal;
		Canvas.DrawColor = GreenColor;
		Canvas.StrLen( PRI(PlayerPawn(Owner).PlayerReplicationInfo).GreenScore, XL, YL );
		Canvas.SetPos( Xpos - XL - 4, Ypos + 32 - 0.5 * YL );
		Canvas.DrawText( PRI(PlayerPawn(Owner).PlayerReplicationInfo).GreenScore, false );
		}
	if ( Numteams > 3 )
		{
		Ypos += 80;
		Gold = PRI(PlayerPawn(Owner).PlayerReplicationInfo).GoldIcon;
		GoldIcon = Texture(DynamicLoadObject(Gold, class'Texture'));
		Canvas.Font = MyFonts.GetHugeFont( Canvas.ClipX );
		Canvas.DrawColor = WhiteColor;
		Canvas.SetPos( Xpos, Ypos );
		Canvas.Style = ERenderStyle.STY_Translucent;
		Canvas.DrawIcon( GoldIcon, 1 );
		Canvas.Style = ERenderStyle.STY_Normal;
		Canvas.DrawColor = GoldColor;
		Canvas.StrLen( PRI(PlayerPawn(Owner).PlayerReplicationInfo).GoldScore, XL, YL );
		Canvas.SetPos( Xpos - XL - 4, Ypos + 32 - 0.5 * YL );
		Canvas.DrawText( PRI(PlayerPawn(Owner).PlayerReplicationInfo).GoldScore, false );
		}
}

// Entry point for string messages.
simulated function Message( PlayerReplicationInfo PRI, coerce string Msg, name MsgType )
{
	local int i;
	local Class<LocalMessage> MessageClass;

	switch (MsgType)
	{
		case 'Say':
			MessageClass = class'SayMessagePlus';
			break;
		case 'TeamSay':
			MessageClass = class'TeamSayMessagePlus';
			break;
		case 'CriticalEvent':
			MessageClass = class'CriticalStringPlus';
			LocalizedMessage( MessageClass, 0, None, None, None, Msg );
			return;
		default:
			MessageClass= class'StringMessagePlus';
			break;
	}
	if ( ClassIsChildOf(MessageClass, class'SayMessagePlus') || 
				     ClassIsChildOf(MessageClass, class'TeamSayMessagePlus') )
	{
		FaceTexture = PRI.TalkTexture;
		FaceTeam = TeamColor[PRI.Team];
		if ( FaceTexture != None )
			FaceTime = Level.TimeSeconds + 3;
		if ( Msg == "" )
			return;
	} 

	for (i=0; i<4; i++)
	{
		if ( ShortMessageQueue[i].Message == None )
		{
			// Add the message here.
			ShortMessageQueue[i].Message = MessageClass;
			ShortMessageQueue[i].Switch = 0;
			ShortMessageQueue[i].RelatedPRI = PRI;
			ShortMessageQueue[i].OptionalObject = None;
			ShortMessageQueue[i].EndOfLife = MessageClass.Default.Lifetime + Level.TimeSeconds;
			if ( MessageClass.Default.bComplexString )
				ShortMessageQueue[i].StringMessage = Msg;
			else
				ShortMessageQueue[i].StringMessage = MessageClass.Static.AssembleString(self,0,PRI,Msg);
			return;
		}
	}

	// No empty slots.  Force a message out.
	for (i=0; i<3; i++)
		CopyMessage(ShortMessageQueue[i],ShortMessageQueue[i+1]);

	ShortMessageQueue[3].Message = MessageClass;
	ShortMessageQueue[3].Switch = 0;
	ShortMessageQueue[3].RelatedPRI = PRI;
	ShortMessageQueue[3].OptionalObject = None;
	ShortMessageQueue[3].EndOfLife = MessageClass.Default.Lifetime + Level.TimeSeconds;
	if ( MessageClass.Default.bComplexString )
		ShortMessageQueue[3].StringMessage = Msg;
	else
		ShortMessageQueue[3].StringMessage = MessageClass.Static.AssembleString(self,0,PRI,Msg);
}

simulated function SetIDColor( Canvas Canvas, int type )
{
	if ( type == 0 )
		Canvas.DrawColor = AltTeamColor[IdentifyTarget.Team] * 0.333 * IdentifyFadeTime;
	else
		Canvas.DrawColor = TeamColor[IdentifyTarget.Team] * 0.333 * IdentifyFadeTime;

}

simulated function bool DrawIdentifyInfo(canvas Canvas)
{
	local float XL, YL, XOffset, X1;
	local Pawn P;

	if ( !Super.DrawIdentifyInfo(Canvas) )
		return false;

	Canvas.StrLen("TEST", XL, YL);
	if( PawnOwner.PlayerReplicationInfo.Team == IdentifyTarget.Team )
	{
		P = Pawn(IdentifyTarget.Owner);
		Canvas.Font = MyFonts.GetSmallFont(Canvas.ClipX);
		if ( P != None )
			DrawTwoColorID(Canvas,IdentifyHealth,string(P.Health), (Canvas.ClipY - 256 * Scale) + 1.5 * YL);
	}
	return true;
}

function DrawTalkFace(Canvas Canvas, int i, float YPos)
{
	if ( !bHideHUD && (PawnOwner.PlayerReplicationInfo != None) && !PawnOwner.PlayerReplicationInfo.bIsSpectator )
	{
		Canvas.Style = ERenderStyle.STY_Normal;
		Canvas.SetPos(FaceAreaOffset, 0);
		Canvas.DrawColor = FaceTeam;
		Canvas.DrawTile(texture'LadrStatic.Static_a00', YPos + 7*Scale, YPos + 7*Scale, 0, 0, texture'FacePanel1'.USize, texture'FacePanel1'.VSize);
		Canvas.DrawColor = WhiteColor;
		Canvas.Style = ERenderStyle.STY_Normal;
		Canvas.SetPos(FaceAreaOffset + 4*Scale, 4*Scale);
		Canvas.DrawTile(FaceTexture, YPos - 1*Scale, YPos - 1*Scale, 0, 0, FaceTexture.USize, FaceTexture.VSize);
		Canvas.Style = ERenderStyle.STY_Translucent;
		Canvas.DrawColor = FaceColor;
		Canvas.SetPos(FaceAreaOffset, 0);
		Canvas.DrawTile(texture'LadrStatic.Static_a00', YPos + 7*Scale, YPos + 7*Scale, 0, 0, texture'LadrStatic.Static_a00'.USize, texture'LadrStatic.Static_a00'.VSize);
		Canvas.DrawColor = WhiteColor;
	}
}

defaultproperties
{
     TeamIcon(0)=Texture'Botpack.Icons.I_TeamR'
     TeamIcon(1)=Texture'Botpack.Icons.I_TeamB'
     TeamIcon(2)=Texture'Botpack.Icons.I_TeamG'
     TeamIcon(3)=Texture'Botpack.Icons.I_TeamY'
     TeamColor(0)=(R=255)
     TeamColor(1)=(G=128,B=255)
     TeamColor(2)=(G=255)
     TeamColor(3)=(R=255,G=255)
     AltTeamColor(0)=(R=200)
     AltTeamColor(1)=(G=94,B=187)
     AltTeamColor(2)=(G=128)
     AltTeamColor(3)=(R=255,G=255,B=128)
     OrderNames(0)=Defend
     OrderNames(1)=Hold
     OrderNames(2)=Attack
     OrderNames(3)=Follow
     OrderNames(4)=Freelance
     OrderNames(5)=Point
     OrderNames(10)=Attack
     OrderNames(11)=Freelance
     NumOrders=5
     ServerInfoClass=Class'Botpack.ServerInfoTeam'
}
